@@ -18,12 +18,10 @@
 #
 """Build an RPM package out of a Git repository"""
 
-import ConfigParser
+from six.moves import configparser
 import os
-import re
 import shutil
 import sys
-from datetime import datetime
 
 import gbp.log
 import gbp.notifications
@@ -79,7 +77,7 @@ def git_archive(repo, spec, output_dir, treeish, prefix, comp_level,
         else:
             git_archive_single(treeish, output, prefix,
                                spec.orig_src['compression'], comp_level,
-                               comp_opts)
+                               comp_opts, spec.orig_src['archive_fmt'])
     except (GitRepositoryError, CommandExecFailed):
         gbp.log.err("Error generating submodules' archives")
         return False
@@ -240,16 +238,19 @@ def git_archive_build_orig(repo, spec, output_dir, options):
 
 def is_native(repo, options):
     """Determine whether a package is native or non-native"""
-    if repo.has_branch(options.upstream_branch):
-        return False
-    # Check remotes, too
-    for remote_branch in repo.get_remote_branches():
-        remote, branch = remote_branch.split('/', 1)
-        if branch == options.upstream_branch:
-            gbp.log.debug("Found upstream branch '%s' from remote '%s'" %
-                          (remote, branch))
+    if options.native.is_auto():
+        if repo.has_branch(options.upstream_branch):
             return False
-    return True
+        # Check remotes, too
+        for remote_branch in repo.get_remote_branches():
+            remote, branch = remote_branch.split('/', 1)
+            if branch == options.upstream_branch:
+                gbp.log.debug("Found upstream branch '%s' from remote '%s'" %
+                               (remote, branch))
+                return False
+        return True
+
+    return options.native.is_on()
 
 
 def setup_builder(options, builder_args):
@@ -277,6 +278,21 @@ def packaging_tag_data(repo, commit, name, version, options):
     return (tag_name, tag_msg)
 
 
+def setup_mock(options):
+    """setup everything to use gbp-builder-mock"""
+    if options.use_mock:
+        options.builder = '/usr/share/git-buildpackage/gbp-builder-mock'
+        options.cleaner = '/bin/true'
+        os.environ['GBP_BUILDER_MOCK_DIST'] = options.mock_dist
+        if options.mock_arch:
+            os.environ['GBP_BUILDER_MOCK_ARCH'] = options.mock_arch
+        if options.mock_root:
+            os.environ['GBP_BUILDER_MOCK_ROOT'] = options.mock_root
+        os.environ['GBP_BUILDER_MOCK_EXPORT_DIR'] = options.export_dir
+        if options.mock_options:
+            os.environ['GBP_BUILDER_MOCK_OPTIONS'] = options.mock_options
+
+
 def create_packaging_tag(repo, commit, name, version, options):
     """Create a packaging/release Git tag"""
     tag_name, tag_msg = packaging_tag_data(repo, commit, name, version, options)
@@ -301,7 +317,7 @@ def build_parser(name, prefix=None, git_treeish=None):
     try:
         parser = GbpOptionParserRpm(command=os.path.basename(name),
                                     prefix=prefix)
-    except ConfigParser.ParsingError as err:
+    except configparser.ParsingError as err:
         gbp.log.err(err)
         return None
 
@@ -334,6 +350,8 @@ def build_parser(name, prefix=None, git_treeish=None):
                     type='tristate')
     parser.add_config_file_option(option_name="vendor", action="store",
                     dest="vendor")
+    parser.add_config_file_option(option_name="native", dest="native",
+                    type='tristate')
     tag_group.add_option("--git-tag", action="store_true", dest="tag",
                     default=False,
                     help="create a tag after a successful build")
@@ -397,6 +415,11 @@ def build_parser(name, prefix=None, git_treeish=None):
     cmd_group.add_config_file_option(option_name="posttag", dest="posttag",
                     help="hook run after a successful tag operation, default "
                          "is '%(posttag)s'")
+    cmd_group.add_boolean_config_file_option(option_name="mock", dest="use_mock")
+    cmd_group.add_config_file_option(option_name="dist", dest="mock_dist")
+    cmd_group.add_config_file_option(option_name="arch", dest="mock_arch")
+    cmd_group.add_config_file_option(option_name="mock-root", dest="mock_root")
+    cmd_group.add_config_file_option(option_name="mock-options", dest="mock_options")
     cmd_group.add_boolean_config_file_option(option_name="hooks", dest="hooks")
     export_group.add_option("--git-no-build", action="store_true",
                     dest="no_build",
@@ -509,6 +532,8 @@ def main(argv):
         if not options.tag_only:
             # Setup builder opts
             setup_builder(options, builder_args)
+            if options.use_mock:
+                setup_mock(options)
 
             # Prepare final export dirs
             export_dir = makedir(options.export_dir)
