@@ -12,8 +12,8 @@
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program; if not, write to the Free Software
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#    along with this program; if not, please see
+#    <http://www.gnu.org/licenses/>
 #
 # Based on the aa-create-git-repo and dom-new-git-repo shell scripts
 """Create a remote Git repository based on the current one"""
@@ -220,9 +220,9 @@ def read_yn():
 
 def setup_branch_tracking(repo, remote, branches):
     repo.add_remote_repo(name=remote['name'], url=remote['url'], fetch=True)
-    gitTrackRemote = GitCommand('branch', ['--set-upstream'])
+    gitTrackRemote = GitCommand('branch', ['--set-upstream-to'])
     for branch in branches:
-        gitTrackRemote(['%s' % branch, '%s/%s' % (remote['name'], branch)])
+        gitTrackRemote(['%s/%s' % (remote['name'], branch), branch])
 
 
 def push_branches(remote, branches):
