@@ -349,13 +349,6 @@ def main(argv):
         return 1
 
     try:
-        if options.download:
-            source = download_orig(args[0])
-        else:
-            source = find_source(options.uscan, args)
-        if not source:
-            return ret
-
         try:
             repo = DebianGitRepository('.')
         except GitRepositoryError:
@@ -368,13 +361,25 @@ def main(argv):
         if not repo.has_branch(options.upstream_branch) and not is_empty:
             raise GbpError(no_upstream_branch_msg % options.upstream_branch)
 
-        (sourcepackage, version) = detect_name_and_version(repo, source, options)
-
         (clean, out) = repo.is_clean()
         if not clean and not is_empty:
             gbp.log.err("Repository has uncommitted changes, commit these first: ")
             raise GbpError(out)
 
+        # Download the source
+        if options.download:
+            source = download_orig(args[0])
+        else:
+            source = find_source(options.uscan, args)
+        if not source:
+            return ret
+
+        (sourcepackage, version) = detect_name_and_version(repo, source, options)
+
+        tag = repo.version_to_tag(options.upstream_tag, version)
+        if repo.has_tag(tag):
+            raise GbpError("Upstream tag '%s' already exists" % tag)
+
         if repo.bare:
             set_bare_repo_options(options)
 
@@ -428,7 +433,6 @@ def main(argv):
                 else:
                     gbp.log.warn("'%s' not an archive, skipping pristine-tar" % source.path)
 
-            tag = repo.version_to_tag(options.upstream_tag, version)
             repo.create_tag(name=tag,
                             msg="Upstream version %s" % version,
                             commit=commit,
