@@ -76,3 +76,25 @@ class TestGuessVersionFromUpstream(testutils.DebianGitTestRepo):
                                                   cp)
 
         self.assertEqual('1.0-1', guessed)
+
+    def test_guess_upstream_tag_zero_release(self):
+        """Guess with existing -0... releases"""
+        cp = testutils.MockedChangeLog('0.9-0vyatta2')
+
+        tagformat = 'upstream/%(version)s'
+        uversion = '0.9'
+        upstream_branch = 'upstream'
+
+        self.add_file('doesnot', 'matter')
+        self.repo.create_branch('upstream')
+        tag = self.repo.version_to_tag(tagformat, uversion)
+        self.repo.create_tag(name=tag, msg="Upstream release %s" % uversion,
+                             sign=False)
+        self.repo.set_branch('master')
+        self.add_file('doesnot2', 'matter')
+
+        guessed = dch.guess_version_from_upstream(self.repo,
+                                                  tagformat,
+                                                  upstream_branch,
+                                                  cp)
+        self.assertEqual(None, guessed)
