@@ -18,12 +18,12 @@
 
 import os
 import shutil
-import urllib2
+from six.moves import urllib
 from nose.plugins.skip import SkipTest
 from nose.tools import assert_raises, eq_, ok_  # pylint: disable=E0611
 from mock import Mock
 
-from gbp.scripts.import_srpm import main as import_srpm
+import gbp.scripts.import_srpm as import_srpm
 from gbp.git import GitRepository
 from gbp.rpm import SrcRpmFile
 
@@ -36,7 +36,7 @@ from tests.component.rpm import RPM_TEST_DATA_DIR as DATA_DIR
 def mock_import(args):
     """Wrapper for import-srpm"""
     # Call import-orig-rpm with added arg0
-    return import_srpm(['arg0'] + args)
+    return import_srpm.main(['arg0'] + args)
 
 
 class TestImportPacked(ComponentTestBase):
@@ -217,8 +217,8 @@ class TestImportPacked(ComponentTestBase):
 class TestImportUnPacked(ComponentTestBase):
     """Test importing of unpacked source rpms"""
 
-    def setup(self):
-        super(TestImportUnPacked, self).setup()
+    def setUp(self):
+        super(TestImportUnPacked, self).setUp()
         # Unpack some source rpms
         os.mkdir('multi-unpack')
         for pkg in ['gbp-test-1.0-1.src.rpm', 'gbp-test2-2.0-0.src.rpm']:
@@ -265,8 +265,8 @@ class TestDownloadImport(ComponentTestBase):
                'master/gbp-test-1.0-1.src.rpm'
         # Mock to use local files instead of really downloading
         local_fn = os.path.join(DATA_DIR, os.path.basename(srpm))
-        urllib2.urlopen = Mock()
-        urllib2.urlopen.return_value = open(local_fn, 'r')
+        import_srpm.urlopen = Mock()
+        import_srpm.urlopen.return_value = open(local_fn, 'r')
 
         eq_(mock_import(['--no-pristine-tar', '--download', srpm]), 0)
         # Check repository state
@@ -277,9 +277,9 @@ class TestDownloadImport(ComponentTestBase):
         """Test graceful failure when trying download from nonexistent url"""
         srpm = 'http://honk.sigxcpu.org/does/not/exist'
         # Do not connect to remote, mock failure
-        urllib2.urlopen = Mock()
-        urllib2.urlopen.side_effect = urllib2.HTTPError(srpm, 404, "Not found",
-                                                        None, None)
+        import_srpm.urlopen = Mock()
+        import_srpm.urlopen.side_effect = urllib.error.HTTPError(srpm, 404, "Not found",
+                                                            None, None)
 
         eq_(mock_import(['--download', srpm]), 1)
         self._check_log(-1, "gbp:error: Download failed: HTTP Error 404")
@@ -297,11 +297,11 @@ class TestPristineTar(ComponentTestBase):
     """Test importing with pristine-tar"""
 
     @classmethod
-    def setup_class(cls):
+    def setUpClass(cls):
         if not os.path.exists('/usr/bin/pristine-tar'):
             raise SkipTest('Skipping %s:%s as pristine-tar tool is not '
                            'available' % (__name__, cls.__name__))
-        super(TestPristineTar, cls).setup_class()
+        super(TestPristineTar, cls).setUpClass()
 
     def test_basic_import_pristine_tar(self):
         """Test importing of non-native src.rpm, with pristine-tar"""
