@@ -233,7 +233,7 @@ def test_get_upstream_branch():
 
 def test_tag():
     """
-    Create a tag named I{tag} and check it's existance
+    Create a tag named I{tag} and check its existance
 
     Methods tested:
          - L{gbp.git.GitRepository.create_tag}
